define(
//begin v1.x content
{
	"HKD_displayName": "Хонгконшки долар",
	"CNY_displayName": "Кинески јуан",
	"JPY_displayName": "Јапански јен",
	"JPY_symbol": "¥",
	"USD_displayName": "Амерички долар",
	"CAD_symbol": "CA$",
	"GBP_displayName": "Британска фунта",
	"CHF_displayName": "Швајцарски франак",
	"CNY_symbol": "CN¥",
	"EUR_displayName": "Евро",
	"GBP_symbol": "£",
	"CAD_displayName": "Канадски долар",
	"USD_symbol": "US$",
	"EUR_symbol": "€",
	"AUD_displayName": "Аустралијски долар",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "AUD"
}
//end v1.x content
);